==> inmobi-4.7.1-sources.jar: com/yodo1/mas/mediation/inmobi/Yodo1MasInMobiInterstitialAdapter.java <==
package com.yodo1.mas.mediation.inmobi;

import android.app.Activity;
import android.text.TextUtils;
import android.util.Log;

import androidx.annotation.NonNull;

import com.inmobi.ads.AdMetaInfo;
import com.inmobi.ads.InMobiAdRequestStatus;
import com.inmobi.ads.InMobiInterstitial;
import com.inmobi.ads.listeners.InterstitialAdEventListener;
import com.yodo1.mas.error.Yodo1MasError;
import com.yodo1.mas.interstitial.Yodo1MasInterstitialAdapterBase;
import com.yodo1.mas.mediation.Yodo1MasAdapterBase;

import java.util.List;
import java.util.Map;

public class Yodo1MasInMobiInterstitialAdapter extends Yodo1MasInterstitialAdapterBase {

    private InMobiInterstitial interstitialAd;

    public Yodo1MasInMobiInterstitialAdapter(List<Yodo1MasAdapterBase.AdId> unitIds) {
        super(unitIds);
    }

    @Override
    public boolean isInterstitialAdLoaded() {
        return interstitialAd != null && interstitialAd.isReady();
    }

    @Override
    public void loadInterstitialAdvert(Activity activity) {
        super.loadInterstitialAdvert(activity);
        String adId = getAdUnitId(false);
        if (TextUtils.isEmpty(adId)) return;

        if (interstitialStatus == Yodo1MasAdapterBase.AdvertStatus.LOADING) return;
        String message = "method: loadInterstitialAdvert, loading interstitial ad...";
        Log.d(TAG, message);

        interstitialStatus = Yodo1MasAdapterBase.AdvertStatus.LOADING;
        interstitialAd = new InMobiInterstitial(activity.getApplicationContext(), Long.parseLong(adId), interstitialListener);
        interstitialAd.load();
    }

    @Override
    public void showInterstitialAdvertFromActivity(Activity activity) {
        super.showInterstitialAdvertFromActivity(activity);
        if (isInterstitialAdLoaded()) {
            String message = "method: showInterstitialAdvert, show interstitial ad...";
            Log.d(TAG, message);
            interstitialAd.show();
        }
    }

    private final InterstitialAdEventListener interstitialListener = new InterstitialAdEventListener() {
        @Override
        public void onAdLoadSucceeded(@NonNull InMobiInterstitial inMobiInterstitial, @NonNull AdMetaInfo adMetaInfo) {
            super.onAdLoadSucceeded(inMobiInterstitial, adMetaInfo);
            String message = "method: onAdLoadSucceeded, interstitial: " + inMobiInterstitial + ", adMetaInfo: " + adMetaInfo;
            Log.d(TAG, message);
            callbackLoad();
        }

        @Override
        public void onAdLoadFailed(@NonNull InMobiInterstitial interstitial, @NonNull InMobiAdRequestStatus status) {
            String message = "method: onAdLoadFailed, interstitial: " + interstitial + ", status: " + status;
            Log.d(TAG, message);
            Yodo1MasError error = new Yodo1MasError(Yodo1MasError.CODE_ADVERT_LOAD_FAIL, TAG + ":{" + message + "}");
            callbackError(error, status.getStatusCode().ordinal(), status.getMessage());
        }

        @Override
        public void onAdDisplayed(@NonNull InMobiInterstitial interstitial, @NonNull AdMetaInfo info) {
            String message = "method: onAdDisplayed, interstitial: " + interstitial + ", info: " + info;
            Log.d(TAG, message);
            callbackOpen();
        }

        @Override
        public void onAdDisplayFailed(@NonNull InMobiInterstitial interstitial) {
            String message = "method: onAdDisplayFailed, interstitial: " + interstitial;
            Log.d(TAG, message);
            Yodo1MasError error = new Yodo1MasError(Yodo1MasError.CODE_ADVERT_SHOW_FAIL, TAG + ":{" + message + "}");
            callbackError(error, 0, message);
        }

        @Override
        public void onAdDismissed(@NonNull InMobiInterstitial interstitial) {
            String message = "method: onAdDisplayed, interstitial: " + interstitial;
            Log.d(TAG, message);
            callbackClose();
        }

        @Override
        public void onAdClicked(@NonNull InMobiInterstitial inMobiInterstitial, Map<Object, Object> map) {
            callbackClick();
        }
    };
}

==> inmobi-4.8.2-sources.jar: com/yodo1/mas/mediation/inmobi/Yodo1MasInMobiInterstitialAdapter.java <==
package com.yodo1.mas.mediation.inmobi;

import android.app.Activity;
import android.text.TextUtils;

import androidx.annotation.NonNull;

import com.inmobi.ads.AdMetaInfo;
import com.inmobi.ads.InMobiAdRequestStatus;
import com.inmobi.ads.InMobiInterstitial;
import com.inmobi.ads.listeners.InterstitialAdEventListener;
import com.yodo1.mas.Yodo1MasLog;
import com.yodo1.mas.error.Yodo1MasError;
import com.yodo1.mas.interstitial.Yodo1MasInterstitialAdapterBase;
import com.yodo1.mas.mediation.Yodo1MasAdapterBase;

import java.util.List;
import java.util.Map;

public class Yodo1MasInMobiInterstitialAdapter extends Yodo1MasInterstitialAdapterBase {

    private InMobiInterstitial interstitialAd;

    public Yodo1MasInMobiInterstitialAdapter(List<Yodo1MasAdapterBase.AdId> unitIds) {
        super(unitIds);
    }

    @Override
    public boolean isInterstitialAdLoaded() {
        return interstitialAd != null && interstitialAd.isReady();
    }

    @Override
    public void loadInterstitialAdvert(Activity activity) {
        super.loadInterstitialAdvert(activity);
        String adId = getAdUnitId(false);
        if (TextUtils.isEmpty(adId)) return;

        if (interstitialStatus == Yodo1MasAdapterBase.AdvertStatus.LOADING) return;
        String message = "method: loadInterstitialAdvert, loading interstitial ad...";
        Yodo1MasLog.v(TAG, message);

        interstitialStatus = Yodo1MasAdapterBase.AdvertStatus.LOADING;
        interstitialAd = new InMobiInterstitial(activity.getApplicationContext(), Long.parseLong(adId), interstitialListener);
        interstitialAd.load();
    }

    @Override
    public void showInterstitialAdvertFromActivity(Activity activity) {
        super.showInterstitialAdvertFromActivity(activity);
        if (isInterstitialAdLoaded()) {
            String message = "method: showInterstitialAdvert, show interstitial ad...";
            Yodo1MasLog.v(TAG, message);
            interstitialAd.show();
        }
    }

    private final InterstitialAdEventListener interstitialListener = new InterstitialAdEventListener() {
        @Override
        public void onAdLoadSucceeded(@NonNull InMobiInterstitial inMobiInterstitial, @NonNull AdMetaInfo adMetaInfo) {
            super.onAdLoadSucceeded(inMobiInterstitial, adMetaInfo);
            String message = "method: onAdLoadSucceeded, interstitial: " + inMobiInterstitial + ", adMetaInfo: " + adMetaInfo;
            Yodo1MasLog.v(TAG, message);
            callbackLoad();
        }

        @Override
        public void onAdLoadFailed(@NonNull InMobiInterstitial interstitial, @NonNull InMobiAdRequestStatus status) {
            String message = "method: onAdLoadFailed, interstitial: " + interstitial + ", status: " + status;
            Yodo1MasLog.v(TAG, message);
            Yodo1MasError error = new Yodo1MasError(Yodo1MasError.CODE_ADVERT_LOAD_FAIL, TAG + ":{" + message + "}");
            callbackError(error, status.getStatusCode().ordinal(), status.getMessage());
        }

        @Override
        public void onAdDisplayed(@NonNull InMobiInterstitial interstitial, @NonNull AdMetaInfo info) {
            String message = "method: onAdDisplayed, interstitial: " + interstitial + ", info: " + info;
            Yodo1MasLog.v(TAG, message);
            callbackOpen();
        }

        @Override
        public void onAdDisplayFailed(@NonNull InMobiInterstitial interstitial) {
            String message = "method: onAdDisplayFailed, interstitial: " + interstitial;
            Yodo1MasLog.v(TAG, message);
            Yodo1MasError error = new Yodo1MasError(Yodo1MasError.CODE_ADVERT_SHOW_FAIL, TAG + ":{" + message + "}");
            callbackError(error, 0, message);
        }

        @Override
        public void onAdDismissed(@NonNull InMobiInterstitial interstitial) {
            String message = "method: onAdDisplayed, interstitial: " + interstitial;
            Yodo1MasLog.v(TAG, message);
            callbackClose();
        }

        @Override
        public void onAdClicked(@NonNull InMobiInterstitial inMobiInterstitial, Map<Object, Object> map) {
            callbackClick();
        }
    };
}
